@@ -14,13 +14,16 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Mapping, Sequence, Type, overload
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import (
+    DatasetTypeType,
     DocumentClassifierModeType,
     LanguageCodeType,
+    ModelTypeType,
     PiiEntitiesDetectionModeType,
     SyntaxLanguageCodeType,
 )
@@ -28,9 +31,11 @@ from .paginator import (
     ListDocumentClassificationJobsPaginator,
     ListDocumentClassifiersPaginator,
     ListDominantLanguageDetectionJobsPaginator,
+    ListEndpointsPaginator,
     ListEntitiesDetectionJobsPaginator,
     ListEntityRecognizersPaginator,
     ListKeyPhrasesDetectionJobsPaginator,
+    ListPiiEntitiesDetectionJobsPaginator,
     ListSentimentDetectionJobsPaginator,
     ListTopicsDetectionJobsPaginator,
 )
@@ -43,9 +48,15 @@ from .type_defs import (
     BatchDetectTargetedSentimentResponseTypeDef,
     ClassifyDocumentResponseTypeDef,
     ContainsPiiEntitiesResponseTypeDef,
+    CreateDatasetResponseTypeDef,
     CreateDocumentClassifierResponseTypeDef,
     CreateEndpointResponseTypeDef,
     CreateEntityRecognizerResponseTypeDef,
+    CreateFlywheelResponseTypeDef,
+    DataSecurityConfigTypeDef,
+    DatasetFilterTypeDef,
+    DatasetInputDataConfigTypeDef,
+    DescribeDatasetResponseTypeDef,
     DescribeDocumentClassificationJobResponseTypeDef,
     DescribeDocumentClassifierResponseTypeDef,
     DescribeDominantLanguageDetectionJobResponseTypeDef,
@@ -53,6 +64,8 @@ from .type_defs import (
     DescribeEntitiesDetectionJobResponseTypeDef,
     DescribeEntityRecognizerResponseTypeDef,
     DescribeEventsDetectionJobResponseTypeDef,
+    DescribeFlywheelIterationResponseTypeDef,
+    DescribeFlywheelResponseTypeDef,
     DescribeKeyPhrasesDetectionJobResponseTypeDef,
     DescribePiiEntitiesDetectionJobResponseTypeDef,
     DescribeResourcePolicyResponseTypeDef,
@@ -70,15 +83,19 @@ from .type_defs import (
     DocumentClassifierFilterTypeDef,
     DocumentClassifierInputDataConfigTypeDef,
     DocumentClassifierOutputDataConfigTypeDef,
+    DocumentReaderConfigTypeDef,
     DominantLanguageDetectionJobFilterTypeDef,
     EndpointFilterTypeDef,
     EntitiesDetectionJobFilterTypeDef,
     EntityRecognizerFilterTypeDef,
     EntityRecognizerInputDataConfigTypeDef,
     EventsDetectionJobFilterTypeDef,
+    FlywheelFilterTypeDef,
+    FlywheelIterationFilterTypeDef,
     ImportModelResponseTypeDef,
     InputDataConfigTypeDef,
     KeyPhrasesDetectionJobFilterTypeDef,
+    ListDatasetsResponseTypeDef,
     ListDocumentClassificationJobsResponseTypeDef,
     ListDocumentClassifiersResponseTypeDef,
     ListDocumentClassifierSummariesResponseTypeDef,
@@ -88,6 +105,8 @@ from .type_defs import (
     ListEntityRecognizersResponseTypeDef,
     ListEntityRecognizerSummariesResponseTypeDef,
     ListEventsDetectionJobsResponseTypeDef,
+    ListFlywheelIterationHistoryResponseTypeDef,
+    ListFlywheelsResponseTypeDef,
     ListKeyPhrasesDetectionJobsResponseTypeDef,
     ListPiiEntitiesDetectionJobsResponseTypeDef,
     ListSentimentDetectionJobsResponseTypeDef,
@@ -103,6 +122,7 @@ from .type_defs import (
     StartDominantLanguageDetectionJobResponseTypeDef,
     StartEntitiesDetectionJobResponseTypeDef,
     StartEventsDetectionJobResponseTypeDef,
+    StartFlywheelIterationResponseTypeDef,
     StartKeyPhrasesDetectionJobResponseTypeDef,
     StartPiiEntitiesDetectionJobResponseTypeDef,
     StartSentimentDetectionJobResponseTypeDef,
@@ -117,7 +137,11 @@ from .type_defs import (
     StopTargetedSentimentDetectionJobResponseTypeDef,
     TagTypeDef,
     TargetedSentimentDetectionJobFilterTypeDef,
+    TaskConfigTypeDef,
     TopicsDetectionJobFilterTypeDef,
+    UpdateDataSecurityConfigTypeDef,
+    UpdateEndpointResponseTypeDef,
+    UpdateFlywheelResponseTypeDef,
     VpcConfigTypeDef,
 )
 
@@ -211,7 +235,7 @@ class ComprehendClient(BaseClient):
     ) -> BatchDetectSentimentResponseTypeDef:
         """
         Inspects a batch of documents and returns an inference of the prevailing
-        sentiment, `POSITIVE` , `NEUTRAL` , `MIXED` , or `NEGATIVE` , in each one.
+        sentiment, `POSITIVE`, `NEUTRAL`, `MIXED`, or `NEGATIVE`, in each one.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.batch_detect_sentiment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#batch_detect_sentiment)
@@ -247,7 +271,14 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#can_paginate)
         """
 
-    def classify_document(self, *, Text: str, EndpointArn: str) -> ClassifyDocumentResponseTypeDef:
+    def classify_document(
+        self,
+        *,
+        EndpointArn: str,
+        Text: str = ...,
+        Bytes: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        DocumentReaderConfig: DocumentReaderConfigTypeDef = ...
+    ) -> ClassifyDocumentResponseTypeDef:
         """
         Creates a new document classification request to analyze a single document in
         real-time, using a previously created and trained custom model and an endpoint.
@@ -276,6 +307,25 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#contains_pii_entities)
         """
 
+    def create_dataset(
+        self,
+        *,
+        FlywheelArn: str,
+        DatasetName: str,
+        InputDataConfig: DatasetInputDataConfigTypeDef,
+        DatasetType: DatasetTypeType = ...,
+        Description: str = ...,
+        ClientRequestToken: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateDatasetResponseTypeDef:
+        """
+        Creates a dataset to upload training or test data for a model associated with a
+        flywheel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.create_dataset)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#create_dataset)
+        """
+
     def create_document_classifier(
         self,
         *,
@@ -304,17 +354,18 @@ class ComprehendClient(BaseClient):
         self,
         *,
         EndpointName: str,
-        ModelArn: str,
         DesiredInferenceUnits: int,
+        ModelArn: str = ...,
         ClientRequestToken: str = ...,
         Tags: Sequence[TagTypeDef] = ...,
-        DataAccessRoleArn: str = ...
+        DataAccessRoleArn: str = ...,
+        FlywheelArn: str = ...
     ) -> CreateEndpointResponseTypeDef:
         """
         Creates a model-specific endpoint for synchronous inference for a previously
         trained custom model For information about endpoints, see [Managing
         endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-
-        endpoints.html)_ .
+        endpoints.html)_.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#create_endpoint)
@@ -342,6 +393,27 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#create_entity_recognizer)
         """
 
+    def create_flywheel(
+        self,
+        *,
+        FlywheelName: str,
+        DataAccessRoleArn: str,
+        DataLakeS3Uri: str,
+        ActiveModelArn: str = ...,
+        TaskConfig: TaskConfigTypeDef = ...,
+        ModelType: ModelTypeType = ...,
+        DataSecurityConfig: DataSecurityConfigTypeDef = ...,
+        ClientRequestToken: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateFlywheelResponseTypeDef:
+        """
+        A flywheel is an Amazon Web Services resource that orchestrates the ongoing
+        training of a model for custom classification or custom entity recognition.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.create_flywheel)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#create_flywheel)
+        """
+
     def delete_document_classifier(self, *, DocumentClassifierArn: str) -> Dict[str, Any]:
         """
         Deletes a previously created document classifier Only those classifiers that are
@@ -367,6 +439,14 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#delete_entity_recognizer)
         """
 
+    def delete_flywheel(self, *, FlywheelArn: str) -> Dict[str, Any]:
+        """
+        Deletes a flywheel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.delete_flywheel)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#delete_flywheel)
+        """
+
     def delete_resource_policy(
         self, *, ResourceArn: str, PolicyRevisionId: str = ...
     ) -> Dict[str, Any]:
@@ -377,6 +457,14 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#delete_resource_policy)
         """
 
+    def describe_dataset(self, *, DatasetArn: str) -> DescribeDatasetResponseTypeDef:
+        """
+        Returns information about the dataset that you specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.describe_dataset)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#describe_dataset)
+        """
+
     def describe_document_classification_job(
         self, *, JobId: str
     ) -> DescribeDocumentClassificationJobResponseTypeDef:
@@ -446,6 +534,24 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#describe_events_detection_job)
         """
 
+    def describe_flywheel(self, *, FlywheelArn: str) -> DescribeFlywheelResponseTypeDef:
+        """
+        Provides configuration information about the flywheel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.describe_flywheel)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#describe_flywheel)
+        """
+
+    def describe_flywheel_iteration(
+        self, *, FlywheelArn: str, FlywheelIterationId: str
+    ) -> DescribeFlywheelIterationResponseTypeDef:
+        """
+        Retrieve the configuration properties of a flywheel iteration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.describe_flywheel_iteration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#describe_flywheel_iteration)
+        """
+
     def describe_key_phrases_detection_job(
         self, *, JobId: str
     ) -> DescribeKeyPhrasesDetectionJobResponseTypeDef:
@@ -516,10 +622,16 @@ class ComprehendClient(BaseClient):
         """
 
     def detect_entities(
-        self, *, Text: str, LanguageCode: LanguageCodeType = ..., EndpointArn: str = ...
+        self,
+        *,
+        Text: str = ...,
+        LanguageCode: LanguageCodeType = ...,
+        EndpointArn: str = ...,
+        Bytes: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        DocumentReaderConfig: DocumentReaderConfigTypeDef = ...
     ) -> DetectEntitiesResponseTypeDef:
         """
-        Inspects text for named entities, and returns information about them.
+        Detects named entities in input text when you use the pre-trained model.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.detect_entities)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#detect_entities)
@@ -550,8 +662,8 @@ class ComprehendClient(BaseClient):
         self, *, Text: str, LanguageCode: LanguageCodeType
     ) -> DetectSentimentResponseTypeDef:
         """
-        Inspects text and returns an inference of the prevailing sentiment (`POSITIVE` ,
-        `NEUTRAL` , `MIXED` , or `NEGATIVE` ).
+        Inspects text and returns an inference of the prevailing sentiment ( `POSITIVE`,
+        `NEUTRAL`, `MIXED`, or `NEGATIVE`).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.detect_sentiment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#detect_sentiment)
@@ -610,6 +722,21 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#import_model)
         """
 
+    def list_datasets(
+        self,
+        *,
+        FlywheelArn: str = ...,
+        Filter: DatasetFilterTypeDef = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
+    ) -> ListDatasetsResponseTypeDef:
+        """
+        List the datasets that you have configured in this Region.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.list_datasets)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#list_datasets)
+        """
+
     def list_document_classification_jobs(
         self,
         *,
@@ -727,6 +854,31 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#list_events_detection_jobs)
         """
 
+    def list_flywheel_iteration_history(
+        self,
+        *,
+        FlywheelArn: str,
+        Filter: FlywheelIterationFilterTypeDef = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
+    ) -> ListFlywheelIterationHistoryResponseTypeDef:
+        """
+        Information about the history of a flywheel iteration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.list_flywheel_iteration_history)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#list_flywheel_iteration_history)
+        """
+
+    def list_flywheels(
+        self, *, Filter: FlywheelFilterTypeDef = ..., NextToken: str = ..., MaxResults: int = ...
+    ) -> ListFlywheelsResponseTypeDef:
+        """
+        Gets a list of the flywheels that you have created.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.list_flywheels)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#list_flywheels)
+        """
+
     def list_key_phrases_detection_jobs(
         self,
         *,
@@ -818,15 +970,16 @@ class ComprehendClient(BaseClient):
     def start_document_classification_job(
         self,
         *,
-        DocumentClassifierArn: str,
         InputDataConfig: InputDataConfigTypeDef,
         OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         JobName: str = ...,
+        DocumentClassifierArn: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
         VpcConfig: VpcConfigTypeDef = ...,
-        Tags: Sequence[TagTypeDef] = ...
+        Tags: Sequence[TagTypeDef] = ...,
+        FlywheelArn: str = ...
     ) -> StartDocumentClassificationJobResponseTypeDef:
         """
         Starts an asynchronous document classification job.
@@ -867,7 +1020,8 @@ class ComprehendClient(BaseClient):
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
         VpcConfig: VpcConfigTypeDef = ...,
-        Tags: Sequence[TagTypeDef] = ...
+        Tags: Sequence[TagTypeDef] = ...,
+        FlywheelArn: str = ...
     ) -> StartEntitiesDetectionJobResponseTypeDef:
         """
         Starts an asynchronous entity detection job for a collection of documents.
@@ -895,6 +1049,17 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#start_events_detection_job)
         """
 
+    def start_flywheel_iteration(
+        self, *, FlywheelArn: str, ClientRequestToken: str = ...
+    ) -> StartFlywheelIterationResponseTypeDef:
+        """
+        Start the flywheel iteration.This operation uses any new datasets to train a new
+        model version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.start_flywheel_iteration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#start_flywheel_iteration)
+        """
+
     def start_key_phrases_detection_job(
         self,
         *,
@@ -1100,8 +1265,9 @@ class ComprehendClient(BaseClient):
         EndpointArn: str,
         DesiredModelArn: str = ...,
         DesiredInferenceUnits: int = ...,
-        DesiredDataAccessRoleArn: str = ...
-    ) -> Dict[str, Any]:
+        DesiredDataAccessRoleArn: str = ...,
+        FlywheelArn: str = ...
+    ) -> UpdateEndpointResponseTypeDef:
         """
         Updates information about the specified endpoint.
 
@@ -1109,6 +1275,21 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#update_endpoint)
         """
 
+    def update_flywheel(
+        self,
+        *,
+        FlywheelArn: str,
+        ActiveModelArn: str = ...,
+        DataAccessRoleArn: str = ...,
+        DataSecurityConfig: UpdateDataSecurityConfigTypeDef = ...
+    ) -> UpdateFlywheelResponseTypeDef:
+        """
+        Update the configuration information for an existing flywheel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.update_flywheel)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#update_flywheel)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_document_classification_jobs"]
@@ -1136,6 +1317,13 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(self, operation_name: Literal["list_endpoints"]) -> ListEndpointsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_entities_detection_jobs"]
@@ -1163,6 +1351,15 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_pii_entities_detection_jobs"]
+    ) -> ListPiiEntitiesDetectionJobsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_sentiment_detection_jobs"]
