@@ -21,30 +21,42 @@ else:
 
 __all__ = (
     "AugmentedManifestsDocumentTypeFormatType",
+    "BlockTypeType",
+    "DatasetDataFormatType",
+    "DatasetStatusType",
+    "DatasetTypeType",
     "DocumentClassifierDataFormatType",
     "DocumentClassifierModeType",
     "DocumentReadActionType",
     "DocumentReadFeatureTypesType",
     "DocumentReadModeType",
+    "DocumentTypeType",
     "EndpointStatusType",
     "EntityRecognizerDataFormatType",
     "EntityTypeType",
+    "FlywheelIterationStatusType",
+    "FlywheelStatusType",
     "InputFormatType",
     "JobStatusType",
     "LanguageCodeType",
     "ListDocumentClassificationJobsPaginatorName",
     "ListDocumentClassifiersPaginatorName",
     "ListDominantLanguageDetectionJobsPaginatorName",
+    "ListEndpointsPaginatorName",
     "ListEntitiesDetectionJobsPaginatorName",
     "ListEntityRecognizersPaginatorName",
     "ListKeyPhrasesDetectionJobsPaginatorName",
+    "ListPiiEntitiesDetectionJobsPaginatorName",
     "ListSentimentDetectionJobsPaginatorName",
     "ListTopicsDetectionJobsPaginatorName",
     "ModelStatusType",
+    "ModelTypeType",
+    "PageBasedErrorCodeType",
     "PartOfSpeechTagTypeType",
     "PiiEntitiesDetectionMaskModeType",
     "PiiEntitiesDetectionModeType",
     "PiiEntityTypeType",
+    "RelationshipTypeType",
     "SentimentTypeType",
     "SplitType",
     "SyntaxLanguageCodeType",
@@ -60,11 +72,24 @@ __all__ = (
 AugmentedManifestsDocumentTypeFormatType = Literal[
     "PLAIN_TEXT_DOCUMENT", "SEMI_STRUCTURED_DOCUMENT"
 ]
+BlockTypeType = Literal["LINE", "WORD"]
+DatasetDataFormatType = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
+DatasetStatusType = Literal["COMPLETED", "CREATING", "FAILED"]
+DatasetTypeType = Literal["TEST", "TRAIN"]
 DocumentClassifierDataFormatType = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
 DocumentClassifierModeType = Literal["MULTI_CLASS", "MULTI_LABEL"]
 DocumentReadActionType = Literal["TEXTRACT_ANALYZE_DOCUMENT", "TEXTRACT_DETECT_DOCUMENT_TEXT"]
 DocumentReadFeatureTypesType = Literal["FORMS", "TABLES"]
 DocumentReadModeType = Literal["FORCE_DOCUMENT_READ_ACTION", "SERVICE_DEFAULT"]
+DocumentTypeType = Literal[
+    "IMAGE",
+    "MS_WORD",
+    "NATIVE_PDF",
+    "PLAIN_TEXT",
+    "SCANNED_PDF",
+    "TEXTRACT_ANALYZE_DOCUMENT_JSON",
+    "TEXTRACT_DETECT_DOCUMENT_TEXT_JSON",
+]
 EndpointStatusType = Literal["CREATING", "DELETING", "FAILED", "IN_SERVICE", "UPDATING"]
 EntityRecognizerDataFormatType = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
 EntityTypeType = Literal[
@@ -78,6 +103,10 @@ EntityTypeType = Literal[
     "QUANTITY",
     "TITLE",
 ]
+FlywheelIterationStatusType = Literal[
+    "COMPLETED", "EVALUATING", "FAILED", "STOPPED", "STOP_REQUESTED", "TRAINING"
+]
+FlywheelStatusType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
 InputFormatType = Literal["ONE_DOC_PER_FILE", "ONE_DOC_PER_LINE"]
 JobStatusType = Literal[
     "COMPLETED", "FAILED", "IN_PROGRESS", "STOPPED", "STOP_REQUESTED", "SUBMITTED"
@@ -88,13 +117,30 @@ LanguageCodeType = Literal[
 ListDocumentClassificationJobsPaginatorName = Literal["list_document_classification_jobs"]
 ListDocumentClassifiersPaginatorName = Literal["list_document_classifiers"]
 ListDominantLanguageDetectionJobsPaginatorName = Literal["list_dominant_language_detection_jobs"]
+ListEndpointsPaginatorName = Literal["list_endpoints"]
 ListEntitiesDetectionJobsPaginatorName = Literal["list_entities_detection_jobs"]
 ListEntityRecognizersPaginatorName = Literal["list_entity_recognizers"]
 ListKeyPhrasesDetectionJobsPaginatorName = Literal["list_key_phrases_detection_jobs"]
+ListPiiEntitiesDetectionJobsPaginatorName = Literal["list_pii_entities_detection_jobs"]
 ListSentimentDetectionJobsPaginatorName = Literal["list_sentiment_detection_jobs"]
 ListTopicsDetectionJobsPaginatorName = Literal["list_topics_detection_jobs"]
 ModelStatusType = Literal[
-    "DELETING", "IN_ERROR", "STOPPED", "STOP_REQUESTED", "SUBMITTED", "TRAINED", "TRAINING"
+    "DELETING",
+    "IN_ERROR",
+    "STOPPED",
+    "STOP_REQUESTED",
+    "SUBMITTED",
+    "TRAINED",
+    "TRAINED_WITH_WARNING",
+    "TRAINING",
+]
+ModelTypeType = Literal["DOCUMENT_CLASSIFIER", "ENTITY_RECOGNIZER"]
+PageBasedErrorCodeType = Literal[
+    "INTERNAL_SERVER_ERROR",
+    "PAGE_CHARACTERS_EXCEEDED",
+    "PAGE_SIZE_EXCEEDED",
+    "TEXTRACT_BAD_PAGE",
+    "TEXTRACT_PROVISIONED_THROUGHPUT_EXCEEDED",
 ]
 PartOfSpeechTagTypeType = Literal[
     "ADJ",
@@ -157,6 +203,7 @@ PiiEntityTypeType = Literal[
     "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER",
     "VEHICLE_IDENTIFICATION_NUMBER",
 ]
+RelationshipTypeType = Literal["CHILD"]
 SentimentTypeType = Literal["MIXED", "NEGATIVE", "NEUTRAL", "POSITIVE"]
 SplitType = Literal["TEST", "TRAIN"]
 SyntaxLanguageCodeType = Literal["de", "en", "es", "fr", "it", "pt"]
@@ -204,6 +251,7 @@ ServiceName = Literal[
     "apprunner",
     "appstream",
     "appsync",
+    "arc-zonal-shift",
     "athena",
     "auditmanager",
     "autoscaling",
@@ -221,6 +269,8 @@ ServiceName = Literal[
     "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
+    "chime-sdk-voice",
+    "cleanrooms",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
@@ -231,9 +281,11 @@ ServiceName = Literal[
     "cloudsearch",
     "cloudsearchdomain",
     "cloudtrail",
+    "cloudtrail-data",
     "cloudwatch",
     "codeartifact",
     "codebuild",
+    "codecatalyst",
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
@@ -270,6 +322,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "docdb-elastic",
     "drs",
     "ds",
     "dynamodb",
@@ -322,9 +375,11 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
+    "iot-roborunner",
     "iot1click-devices",
     "iot1click-projects",
     "iotanalytics",
@@ -339,15 +394,18 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "kendra-ranking",
     "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
@@ -359,6 +417,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-linux-subscriptions",
     "license-manager-user-subscriptions",
     "lightsail",
     "location",
@@ -398,7 +457,10 @@ ServiceName = Literal[
     "network-firewall",
     "networkmanager",
     "nimble",
+    "oam",
+    "omics",
     "opensearch",
+    "opensearchserverless",
     "opsworks",
     "opsworkscm",
     "organizations",
@@ -412,6 +474,7 @@ ServiceName = Literal[
     "pinpoint-email",
     "pinpoint-sms-voice",
     "pinpoint-sms-voice-v2",
+    "pipes",
     "polly",
     "pricing",
     "privatenetworks",
@@ -428,6 +491,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -446,12 +510,16 @@ ServiceName = Literal[
     "sagemaker-a2i-runtime",
     "sagemaker-edge",
     "sagemaker-featurestore-runtime",
+    "sagemaker-geospatial",
+    "sagemaker-metrics",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
     "securityhub",
+    "securitylake",
     "serverlessrepo",
     "service-quotas",
     "servicecatalog",
@@ -461,6 +529,7 @@ ServiceName = Literal[
     "sesv2",
     "shield",
     "signer",
+    "simspaceweaver",
     "sms",
     "sms-voice",
     "snow-device-management",
@@ -470,6 +539,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssm-sap",
     "sso",
     "sso-admin",
     "sso-oidc",
@@ -483,6 +553,7 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
@@ -516,9 +587,11 @@ PaginatorName = Literal[
     "list_document_classification_jobs",
     "list_document_classifiers",
     "list_dominant_language_detection_jobs",
+    "list_endpoints",
     "list_entities_detection_jobs",
     "list_entity_recognizers",
     "list_key_phrases_detection_jobs",
+    "list_pii_entities_detection_jobs",
     "list_sentiment_detection_jobs",
     "list_topics_detection_jobs",
 ]
