@@ -13,9 +13,11 @@ Usage::
         ListDocumentClassificationJobsPaginator,
         ListDocumentClassifiersPaginator,
         ListDominantLanguageDetectionJobsPaginator,
+        ListEndpointsPaginator,
         ListEntitiesDetectionJobsPaginator,
         ListEntityRecognizersPaginator,
         ListKeyPhrasesDetectionJobsPaginator,
+        ListPiiEntitiesDetectionJobsPaginator,
         ListSentimentDetectionJobsPaginator,
         ListTopicsDetectionJobsPaginator,
     )
@@ -26,9 +28,11 @@ Usage::
     list_document_classification_jobs_paginator: ListDocumentClassificationJobsPaginator = client.get_paginator("list_document_classification_jobs")
     list_document_classifiers_paginator: ListDocumentClassifiersPaginator = client.get_paginator("list_document_classifiers")
     list_dominant_language_detection_jobs_paginator: ListDominantLanguageDetectionJobsPaginator = client.get_paginator("list_dominant_language_detection_jobs")
+    list_endpoints_paginator: ListEndpointsPaginator = client.get_paginator("list_endpoints")
     list_entities_detection_jobs_paginator: ListEntitiesDetectionJobsPaginator = client.get_paginator("list_entities_detection_jobs")
     list_entity_recognizers_paginator: ListEntityRecognizersPaginator = client.get_paginator("list_entity_recognizers")
     list_key_phrases_detection_jobs_paginator: ListKeyPhrasesDetectionJobsPaginator = client.get_paginator("list_key_phrases_detection_jobs")
+    list_pii_entities_detection_jobs_paginator: ListPiiEntitiesDetectionJobsPaginator = client.get_paginator("list_pii_entities_detection_jobs")
     list_sentiment_detection_jobs_paginator: ListSentimentDetectionJobsPaginator = client.get_paginator("list_sentiment_detection_jobs")
     list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator("list_topics_detection_jobs")
     ```
@@ -41,18 +45,22 @@ from .type_defs import (
     DocumentClassificationJobFilterTypeDef,
     DocumentClassifierFilterTypeDef,
     DominantLanguageDetectionJobFilterTypeDef,
+    EndpointFilterTypeDef,
     EntitiesDetectionJobFilterTypeDef,
     EntityRecognizerFilterTypeDef,
     KeyPhrasesDetectionJobFilterTypeDef,
     ListDocumentClassificationJobsResponseTypeDef,
     ListDocumentClassifiersResponseTypeDef,
     ListDominantLanguageDetectionJobsResponseTypeDef,
+    ListEndpointsResponseTypeDef,
     ListEntitiesDetectionJobsResponseTypeDef,
     ListEntityRecognizersResponseTypeDef,
     ListKeyPhrasesDetectionJobsResponseTypeDef,
+    ListPiiEntitiesDetectionJobsResponseTypeDef,
     ListSentimentDetectionJobsResponseTypeDef,
     ListTopicsDetectionJobsResponseTypeDef,
     PaginatorConfigTypeDef,
+    PiiEntitiesDetectionJobFilterTypeDef,
     SentimentDetectionJobFilterTypeDef,
     TopicsDetectionJobFilterTypeDef,
 )
@@ -61,9 +69,11 @@ __all__ = (
     "ListDocumentClassificationJobsPaginator",
     "ListDocumentClassifiersPaginator",
     "ListDominantLanguageDetectionJobsPaginator",
+    "ListEndpointsPaginator",
     "ListEntitiesDetectionJobsPaginator",
     "ListEntityRecognizersPaginator",
     "ListKeyPhrasesDetectionJobsPaginator",
+    "ListPiiEntitiesDetectionJobsPaginator",
     "ListSentimentDetectionJobsPaginator",
     "ListTopicsDetectionJobsPaginator",
 )
@@ -133,6 +143,21 @@ class ListDominantLanguageDetectionJobsPaginator(Paginator):
         """
 
 
+class ListEndpointsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEndpoints)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listendpointspaginator)
+    """
+
+    def paginate(
+        self, *, Filter: EndpointFilterTypeDef = ..., PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListEndpointsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEndpoints.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listendpointspaginator)
+        """
+
+
 class ListEntitiesDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
@@ -187,6 +212,24 @@ class ListKeyPhrasesDetectionJobsPaginator(Paginator):
         """
 
 
+class ListPiiEntitiesDetectionJobsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListPiiEntitiesDetectionJobs)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listpiientitiesdetectionjobspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        Filter: PiiEntitiesDetectionJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListPiiEntitiesDetectionJobsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListPiiEntitiesDetectionJobs.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listpiientitiesdetectionjobspaginator)
+        """
+
+
 class ListSentimentDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
